<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public
 * @author     Biuro <info@biuro.lt>
 */
class Biuro_Contacts_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct( $plugin_name, $version ) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Biuro_Contacts_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Biuro_Contacts_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        // wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/biuro-contacts-public.css', array(), $this->version, 'all' );

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Biuro_Contacts_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Biuro_Contacts_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        // wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/biuro-contacts-public.js', array( 'jquery' ), $this->version, false );

    }


    /**
     * Processes shortcode biuro-contacts--employees
     *
     * @param   array   $attr       The attributes from the shortcode
     *
     * @return  mixed   $output     Output of the buffer
     */
    public function employees_form( $atts ) {
        $response = false;

        ob_start();

        if ( isset( $_POST['action-submit'] ) ) :
            $response = true;
        endif;

        include 'partials/biuro-contacts-public--employees.php';

        $output = ob_get_contents();

        ob_end_clean();

        return $output;
    } // employees_form()

    /**
     * Processes shortcode biuro-contacts--employees
     *
     * @param   array   $attr       The attributes from the shortcode
     *
     * @return  mixed   $output     Output of the buffer
     */
    public function employers_quick_form( $attr = array() ) {

        // $args = shortcode_atts(
        //     array(
        //         'arg1'   => 'arg1',
        //         'arg2'   => 'arg2',
        //     ),
        //     $atts
        // );

        $response = false;

        ob_start();

        if ( isset( $_POST['submit'] ) ) :
            $response = true;
        endif;

        include 'partials/biuro-contacts-public--employers-quick.php';

        $output = ob_get_contents();

        ob_end_clean();

        return $output;
    } // employees_form()


    /**
     * Processes shortcode biuro-contacts--employers
     *
     * @param   array   $attr       The attributes from the shortcode
     *
     * @return  mixed   $output     Output of the buffer
     */
    public function employers_form( $attr = array() ) {
        $response = false;

        ob_start();

        if ( isset( $_POST['action-submit'] ) ) :
            $response = true;
        endif;

        include 'partials/biuro-contacts-public--employers.php';

        $output = ob_get_contents();

        ob_end_clean();

        return $output;
    } // employers_form()

    /**
     * Processes shortcode biuro-contacts--position
     *
     * @param   array   $attr       The attributes from the shortcode
     *
     * @return  mixed   $output     Output of the buffer
     */
    public function position_form( $attr = array() ) {
        $response = false;

        ob_start();

        if ( isset( $_POST['action-submit'] ) ) :
            $response = true;
        endif;

        include 'partials/biuro-contacts-public--position.php';

        $output = ob_get_contents();

        ob_end_clean();

        return $output;
    } // position_form()




    /**
     * May override the default upload path.
     * /wp-content/uploads/{folder}/
     *
     * @param   array   $dir
     * @return  array
     */
    function change_upload_dir( $dir ) {
        return array(
            'path'   => $dir['basedir'] . '/{folder}',
            'url'    => $dir['baseurl'] . '/{folder}',
            'subdir' => '/{folder}',
        ) + $dir;
    }


    /**
     * Processes shortcode biuro-contacts--employees
     *
     * @param   array   $attr       The attributes from the shortcode
     *
     * @return  mixed   $output     Output of the buffer
     */
    public function employees_quick_form( $attr = array() ) {

        // $args = shortcode_atts(
        //     array(
        //         'arg1'   => 'arg1',
        //         'arg2'   => 'arg2',
        //     ),
        //     $atts
        // );

        // $response = false;

        ob_start();

        // if ( isset( $_POST['submit'] ) ) :
        //     $response = true;
        // endif;

        include 'partials/biuro-contacts-public--employees-quick.php';

        $output = ob_get_contents();

        ob_end_clean();

        return $output;
    } // employees_form()

    public function employees_quick_post() {
        // debug($_POST); //$_POST variables should be accessible now

        $nonce = $_POST['_wpnonce'];
        $referer = $_POST['_wp_http_referer'];


        if ( !isset( $nonce ) || !wp_verify_nonce($nonce, 'employees_quick_post_nonce' ) ) {
            // Nonce not match
            // Diplay some error
            wp_redirect( $referer );
            exit;
        }

        /*
         * May prehandle file upload
         */
        // Set an array containing a list of acceptable formats
        // $allowed_file_types = array('image/jpg','image/jpeg','image/gif','image/png');
        // $allowed_file_types = array('doc','docx','pdf', 'rtf', 'jpg', 'jpeg', 'gif', 'png');
        // $allowed_file_types = array('doc','docx','pdf');
        $allowed_file_types = array('application/pdf', 'application/msword', 'application/vnd.openxmlformats-officedocument.wordprocessingml.document');
        // Check file types
        foreach( $_FILES as $file ) {
            // Get the type of the uploaded file. This is returned as "type/extension"
            $arr_file_type = wp_check_filetype( basename( $file['name'] ) );
            $uploaded_file_type = $arr_file_type['type'];
            if( ! in_array( $uploaded_file_type, $allowed_file_types ) ) {
                // Diplay some error
                wp_redirect( $referer );
                exit;
            }
        }

        // delog($nonce, 'nonce');
        // Optional: Now you can redirect the user to your confirmation page using wp_redirect()
        // ob_start();
        wp_redirect( $referer );
        exit;

        // wp_redirect(admin_url('admin.php?page=' . $_POST['_wp_http_referer']));
        // die();
        //apparently when finished, die(); is required.
    }

    public function employers_quick_post() {
        // debug($_POST); //$_POST variables should be accessible now

        //Optional: Now you can redirect the user to your confirmation page using wp_redirect()
        // ob_start();
        // wp_redirect($_POST['_wp_http_referer']);
        exit;

        // wp_redirect(admin_url('admin.php?page=' . $_POST['_wp_http_referer']));
        // die();
        //apparently when finished, die(); is required.
    }
}
